/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla.
 *
 * The Initial Developer of the Original Code is
 * Sun Microsystem.
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Joshua Xia <joshua.xia@sun.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

%{C++

#define NS_JVMAUTHTOOLS_CID                          \
{ /* d8e716f9-c96e-4e84-ab12-980f5567e2a4 */         \
    0xd8e716f9,                                      \
    0xc96e,                                          \
    0x4e84,                                          \
    {0xab, 0x12, 0x98, 0x0f, 0x55, 0x67, 0xe2, 0xa4} \
}

%}

[ptr] native const_char_ptr(const char);

[noscript, uuid(078a1b99-6be2-4a57-a749-378f4a506097)]
interface nsIAuthenticationInfo : nsISupports
{
   /** 
    * AuthenticationInfo (username/password pair)
    */

   readonly attribute const_char_ptr  username;
   readonly attribute const_char_ptr  password;
};

[noscript, uuid(82274a32-a196-42ee-8e3b-fcb73e339518)]
interface nsIJVMAuthTools : nsISupports
{
    /**
     * Export AuthenticationInfo interface to JPI.
     *
     * @param protocol               the protocol that support (http/https)
     * @param host                   host name
     * @param port                   port number
     * @param scheme                 scheme
     * @param realm                  realm
     * @param nsIAuthenticationInfo  the AuthenticationInfo interface
     *                               that export
     *
     * @return  	             NS_OK if success, other if fail
     */

    nsIAuthenticationInfo GetAuthenticationInfo(in string protocol,
                                                in string host,
                                                in PRInt32 port,
                                                in string scheme,
                                                in string realm);
	
    /**
     * Import username/password pair from JPI.
     *
     * @param protocol  the protocol that support (http/https)
     * @param host      host name
     * @param port      port number
     * @param scheme    scheme
     * @param realm     realm
     * @param username  user name
     * @param password  password
     *
     * @return          NS_OK if success, other if fail
     */
    
    void SetAuthenticationInfo(in string protocol,
                               in string host,
                               in PRInt32 port,
                               in string scheme,
                               in string realm,
                               in string username,
                               in string password);

};